FCancellationTokenSourceTimeout class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
isActive → bool
no setter
isCancellationRequested → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → FCancellationToken
no setterinherited

Methods

cancel() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preventTimeout() → void
After call the method, the instance behaves is as SimpleCancellationTokenSource
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited