FException class

Inheritance
Implementers

Constructors

FException([String? message, FException? innerException])

Properties

hashCode → int
The hash code for this object.
no setterinherited
innerException → FException?
final
message → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
The stack trace at the point where this error was first thrown.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

wrapIfNeeded(Object likeError, [StackTrace? stackTrace]) → FException