FExceptionNativeErrorWrapper class

Inheritance

Constructors

FExceptionNativeErrorWrapper(Error nativeError)

Properties

hashCode → int
The hash code for this object.
no setterinherited
innerException → FException?
finalinherited
message → String
no setteroverride
nativeError → Error
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
The stack trace at the point where this error was first thrown.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited