FExecutionContext class

Implementers

Constructors

FExecutionContext(FExecutionContext? prevContext)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
prevContext → FExecutionContext?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultExecutionContext → FExecutionContext
Provide default execution context.
no setter
emptyExecutionContext → FExecutionContext
Provide empty execution context. Usually used as root of execution context chain.
no setter

Static Methods

findExecutionContext<T extends FExecutionContext>(FExecutionContext context) → T?
Obtain a closest instance of typed FExecutionContext that encloses the given context.
getExecutionContext<T extends FExecutionContext>(FExecutionContext context) → T
Obtain a closest instance of typed FExecutionContext that encloses the given context.
listExecutionContexts<T extends FExecutionContext>(FExecutionContext context) → List<T>