FDisposableBase class abstract

Implemented types
Implementers

Constructors

FDisposableBase()

Properties

disposed → bool
no setter
disposing → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose() → FutureOr<void>
toString() → String
A string representation of this object.
inherited
verifyNotDisposed() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited