FInitableBase class abstract

Implemented types

Constructors

FInitableBase()

Properties

disposed → bool
no setteroverride
disposing → bool
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
initExecutionContext → FExecutionContext
@remark Defined as property to be able to use inside dispose()
no setter
initialized → bool
no setter
initializing → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → Future<void>
override
init(FExecutionContext executionContext) → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose() → FutureOr<void>
Override this method to insert own logic at disposing phase
override
onInit() → FutureOr<void>
Override this method to insert own logic at initialize phase
toString() → String
A string representation of this object.
inherited
verifyInitialized() → void
verifyInitializedAndNotDisposed() → void
verifyNotDisposed() → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited