FLogger class abstract

Implementers

Constructors

FLogger()
const
FLogger.create(String? loggerName)
Factory constructor
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isDebugEnabled → bool
no setter
isErrorEnabled → bool
no setter
isFatalEnabled → bool
no setter
isInfoEnabled → bool
no setter
isTraceEnabled → bool
no setter
isWarnEnabled → bool
no setter
name → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug(dynamic labelsOrExecutionContext, dynamic messageOrMessageFactory, [FException? ex]) → void
There two overloads
error(dynamic labelsOrExecutionContext, dynamic messageOrMessageFactory) → void
fatal(dynamic labelsOrExecutionContext, dynamic messageOrMessageFactory) → void
info(dynamic labelsOrExecutionContext, dynamic messageOrMessageFactory) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
trace(dynamic labelsOrExecutionContext, dynamic messageOrMessageFactory, [FException? ex]) → void
There several overloads
warn(dynamic labelsOrExecutionContext, dynamic messageOrMessageFactory) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

setLoggerFactory(FLoggerFactory factory) → void