FLoggerBase class abstract

Inheritance
Implementers

Constructors

FLoggerBase(String? loggerName)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isDebugEnabled → bool
no setteroverride
isErrorEnabled → bool
no setteroverride
isFatalEnabled → bool
no setteroverride
isInfoEnabled → bool
no setteroverride
isTraceEnabled → bool
no setteroverride
isWarnEnabled → bool
no setteroverride
name → String?
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug(dynamic labelsOrExecutionContext, dynamic messageOrMessageFactory, [FException? ex]) → void
There two overloads
override
error(dynamic labelsOrExecutionContext, dynamic messageOrMessageFactory) → void
override
fatal(dynamic labelsOrExecutionContext, dynamic messageOrMessageFactory) → void
override
info(dynamic labelsOrExecutionContext, dynamic messageOrMessageFactory) → void
override
isLevelEnabled(FLoggerLevel level) → bool
log(FLoggerLevel level, FLoggerLabels labels, String message, [FException? exception]) → void
Override this method to implement custom logger
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
trace(dynamic labelsOrExecutionContext, dynamic messageOrMessageFactory, [FException? ex]) → void
There several overloads
override
warn(dynamic labelsOrExecutionContext, dynamic messageOrMessageFactory) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited