FLoggerConsole class

Inheritance

Constructors

FLoggerConsole.create(String? loggerName, [FLoggerLevel? level])
Factory constructor
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isDebugEnabled → bool
no setterinherited
isErrorEnabled → bool
no setterinherited
isFatalEnabled → bool
no setterinherited
isInfoEnabled → bool
no setterinherited
isTraceEnabled → bool
no setterinherited
isWarnEnabled → bool
no setterinherited
name → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug(dynamic labelsOrExecutionContext, dynamic messageOrMessageFactory, [FException? ex]) → void
There two overloads
inherited
error(dynamic labelsOrExecutionContext, dynamic messageOrMessageFactory) → void
inherited
fatal(dynamic labelsOrExecutionContext, dynamic messageOrMessageFactory) → void
inherited
info(dynamic labelsOrExecutionContext, dynamic messageOrMessageFactory) → void
inherited
isLevelEnabled(FLoggerLevel level) → bool
override
log(FLoggerLevel level, FLoggerLabels labels, String message, [FException? exception]) → void
Override this method to implement custom logger
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
trace(dynamic labelsOrExecutionContext, dynamic messageOrMessageFactory, [FException? ex]) → void
There several overloads
inherited
warn(dynamic labelsOrExecutionContext, dynamic messageOrMessageFactory) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited