FLoggerLabelsExecutionContext class

Inheritance

Constructors

FLoggerLabelsExecutionContext(FExecutionContext prevContext, FLoggerLabels? loggerLabels)

Properties

hashCode → int
The hash code for this object.
no setterinherited
loggerLabels → FLoggerLabels
no setter
prevContext → FExecutionContext?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited