FLoggerLevel class

Constructors

FLoggerLevel.parse(String value)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator <(FLoggerLevel other) → bool
operator <=(FLoggerLevel other) → bool
operator ==(Object other) → bool
The equality operator.
inherited
operator >(FLoggerLevel other) → bool
operator >=(FLoggerLevel other) → bool

Constants

debug → const FLoggerLevel
error → const FLoggerLevel
fatal → const FLoggerLevel
info → const FLoggerLevel
trace → const FLoggerLevel
warn → const FLoggerLevel