FSqlData class abstract

Properties

asBinary → Uint8List
no setter
asBinaryNullable → Uint8List?
no setter
asBoolean → bool
no setter
asBooleanNullable → bool?
no setter
asDate → DateTime
no setter
asDateNullable → DateTime?
no setter
asDecimal → FDecimal
no setter
asDecimalNullable → FDecimal?
no setter
asInteger → int
no setter
asIntegerNullable → int?
no setter
asString → String
no setter
asStringNullable → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited